@@ -28,6 +28,7 @@ from mvpa2.datasets.base import Dataset
 #
 # and may be some others
 
+
 class OneWayAnova(FeaturewiseMeasure):
     """`FeaturewiseMeasure` that performs a univariate ANOVA.
 
@@ -56,16 +57,14 @@ class OneWayAnova(FeaturewiseMeasure):
         kwargs['auto_train'] = kwargs.get('auto_train', True)
         FeaturewiseMeasure.__init__(self, space=space, **kwargs)
 
-
     def __repr__(self, prefixes=None):
         if prefixes is None:
             prefixes = []
         if self.get_space() != 'targets':
-            prefixes = prefixes + ['targets_attr=%r' % (self.get_space())]
+            prefixes += ['targets_attr=%r' % (self.get_space())]
         return \
             super(FeaturewiseMeasure, self).__repr__(prefixes=prefixes)
 
-
     def _call(self, dataset):
         # This code is based on SciPy's stats.f_oneway()
         # Copyright (c) Gary Strangman.  All rights reserved
@@ -79,32 +78,37 @@ class OneWayAnova(FeaturewiseMeasure):
         ul = targets_sa.unique
 
         na = len(ul)
-        bign = float(dataset.nsamples)
         alldata = dataset.samples
 
         # total squares of sums
-        sostot = np.sum(alldata, axis=0)
+        # determine data-dtype for derived "sum of" measurements, which we need
+        # to have as float for proper divisions
+        so_dtype = np.float if np.issubdtype(alldata.dtype, np.integer) else alldata.dtype
+        bign = dataset.nsamples
+
+        sostot = np.sum(alldata, axis=0, dtype=so_dtype)
         sostot *= sostot
         sostot /= bign
 
         # total sum of squares
-        sstot = np.sum(alldata * alldata, axis=0) - sostot
+        sstot = np.sum(alldata * alldata, axis=0, dtype=so_dtype) - sostot
 
         # between group sum of squares
-        ssbn = 0
+        ssbn = np.zeros(dataset.nfeatures, dtype=so_dtype)
         for l in ul:
             # all samples for the respective label
             d = alldata[labels == l]
-            sos = np.sum(d, axis=0)
+            sos = np.sum(d, axis=0, dtype=so_dtype)
             sos *= sos
-            ssbn += sos / float(len(d))
+            sos /= len(d)  # inplace so we don't demand new temp storage
+            ssbn += sos
 
         ssbn -= sostot
         # within
         sswn = sstot - ssbn
 
         # degrees of freedom
-        dfbn = na-1
+        dfbn = na - 1
         dfwn = bign - na
 
         # mean sums of squares
@@ -148,7 +152,7 @@ class CompoundOneWayAnova(OneWayAnova):
         # Lets create a very shallow copy of a dataset with just
         # samples and targets_attr
         dataset_mod = Dataset(dataset.samples,
-                              sa={self.get_space() : labels})
+                              sa={self.get_space(): labels})
         results = []
         for ul in targets_sa.unique:
             labels[orig_labels == ul] = 1
