@@ -10,6 +10,7 @@
 
 import re
 import os
+from os.path import join as pathjoin
 import unittest
 from tempfile import mkstemp
 import numpy as np
@@ -96,7 +97,7 @@ class IOHelperTests(unittest.TestCase):
 
 
     def test_samples_attributes(self):
-        sa = SampleAttributes(os.path.join(pymvpa_dataroot,
+        sa = SampleAttributes(pathjoin(pymvpa_dataroot,
                                            'attributes_literal.txt'),
                               literallabels=True)
 
@@ -162,7 +163,7 @@ class IOHelperTests(unittest.TestCase):
         except WindowsError:
             pass
 
-        d = FslEV3(os.path.join(pymvpa_dataroot, 'fslev3.txt'))
+        d = FslEV3(pathjoin(pymvpa_dataroot, 'fslev3.txt'))
         ev = d.to_events()
         self.assertTrue(len(ev) == 3)
         self.assertTrue([e['duration'] for e in ev] == [9] * 3)
@@ -181,7 +182,7 @@ class IOHelperTests(unittest.TestCase):
 
 
     def test_fsl_ev2(self):
-        attr = SampleAttributes(os.path.join(pymvpa_dataroot, 'smpl_attr.txt'))
+        attr = SampleAttributes(pathjoin(pymvpa_dataroot, 'smpl_attr.txt'))
 
         # check header (sort because order in dict is unpredictable)
         self.assertTrue(sorted(attr.keys()) == \
@@ -192,7 +193,7 @@ class IOHelperTests(unittest.TestCase):
     def test_bv_rtc(self):
         """Simple testing of reading RTC files from BrainVoyager"""
 
-        attr = BrainVoyagerRTC(os.path.join(pymvpa_dataroot, 'bv', 'smpl_model.rtc'))
+        attr = BrainVoyagerRTC(pathjoin(pymvpa_dataroot, 'bv', 'smpl_model.rtc'))
         self.assertEqual(attr.ncolumns, 4, "We must have 4 colums")
         self.assertEqual(attr.nrows, 147, "We must have 147 rows")
 
@@ -207,7 +208,7 @@ class IOHelperTests(unittest.TestCase):
     def testdesign2labels(self):
         """Simple testing of helper Design2Labels"""
 
-        attr = BrainVoyagerRTC(os.path.join(pymvpa_dataroot, 'bv', 'smpl_model.rtc'))
+        attr = BrainVoyagerRTC(pathjoin(pymvpa_dataroot, 'bv', 'smpl_model.rtc'))
         labels0 = design2labels(attr, baseline_label='silence')
         labels = design2labels(attr, baseline_label='silence',
                                 func=lambda x:x > 0.5)
@@ -224,7 +225,7 @@ class IOHelperTests(unittest.TestCase):
 
 
     def testlabels2chunks(self):
-        attr = BrainVoyagerRTC(os.path.join(pymvpa_dataroot, 'bv', 'smpl_model.rtc'))
+        attr = BrainVoyagerRTC(pathjoin(pymvpa_dataroot, 'bv', 'smpl_model.rtc'))
         labels = design2labels(attr, baseline_label='silence')
         self.assertRaises(ValueError, labels2chunks, labels, 'bugga')
         chunks = labels2chunks(labels)
@@ -237,20 +238,20 @@ class IOHelperTests(unittest.TestCase):
 
 
     def test_sensor_locations(self):
-        sl = XAVRSensorLocations(os.path.join(pymvpa_dataroot, 'xavr1010.dat'))
+        sl = XAVRSensorLocations(pathjoin(pymvpa_dataroot, 'xavr1010.dat'))
 
         for var in ['names', 'pos_x', 'pos_y', 'pos_z']:
             self.assertTrue(len(eval('sl.' + var)) == 31)
 
 
     def test_fsl_glm_design(self):
-        glm = FslGLMDesign(os.path.join(pymvpa_dataroot, 'glm.mat'))
+        glm = FslGLMDesign(pathjoin(pymvpa_dataroot, 'glm.mat'))
 
         self.assertTrue(glm.mat.shape == (850, 6))
         self.assertTrue(len(glm.ppheights) == 6)
 
     def test_read_fsl_design(self):
-        fname = os.path.join(pymvpa_dataroot,
+        fname = pathjoin(pymvpa_dataroot,
                              'sample_design.fsf')
         # use our function
         design = read_fsl_design(fname)
